@@ -29,6 +29,7 @@
 (require 'gnus)
 (require 'gnus-sum)
 (require 'gnus-range)
+(require 'message)
 
 (defcustom gnus-global-score-files nil
   "List of global score files and directories.
@@ -1000,6 +1001,7 @@ SCORE is the score to add."
     (gnus-make-directory (file-name-directory file))
     (setq gnus-score-edit-buffer (find-file-noselect file))
     (gnus-configure-windows 'edit-score)
+    (select-window (get-buffer-window gnus-score-edit-buffer))
     (gnus-score-mode)
     (setq gnus-score-edit-exit-function 'gnus-score-edit-done)
     (make-local-variable 'gnus-prev-winconf)
@@ -1083,7 +1085,7 @@ SCORE is the score to add."
       ;; Perform possible decays.
       (when gnus-decay-scores
 	(when (or (not decay)
-		  (gnus-decay-scores alist (gnus-time-to-day (current-time))))
+		  (gnus-decay-scores alist decay))
 	  (gnus-score-set 'touched '(t) alist)
 	  (gnus-score-set 'decay (list (gnus-time-to-day (current-time))))))
       ;; We do not respect eval and files atoms from global score
@@ -1275,8 +1277,7 @@ SCORE is the score to add."
 	  (erase-buffer)
 	  (let (emacs-lisp-mode-hook)
 	    (if (string-match
-		 (concat (regexp-quote gnus-adaptive-file-suffix)
-			 "$")
+		 (concat (regexp-quote gnus-adaptive-file-suffix) "$")
 		 file)
 		;; This is an adaptive score file, so we do not run
 		;; it through `pp'.  These files can get huge, and
@@ -1359,6 +1360,7 @@ SCORE is the score to add."
 	  (save-excursion
 	    (set-buffer (get-buffer-create "*Headers*"))
 	    (buffer-disable-undo (current-buffer))
+	    (message-clone-locals gnus-summary-buffer)
 
 	    ;; Set the global variant of this variable.
 	    (setq gnus-current-score-file current-score-file)
@@ -2730,7 +2732,7 @@ If ADAPT, return the home adaptive file instead."
   "Decay SCORE according to `gnus-score-decay-constant' and `gnus-score-decay-scale'."
   (floor
    (- score
-      (* (if (< score 0) 1 -1)
+      (* (if (< score 0) -1 1)
 	 (min (abs score)
 	      (max gnus-score-decay-constant
 		   (* (abs score)
